<?php
/**
 * Integration with debloat plugin.
 */
class Bunyad_Theme_Debloat
{
	public $allow_selectors = [];

	public function __construct()
	{
		add_action('wp', [$this, 'setup']);
	}

	public function setup()
	{
		if (is_admin()) {
			return;
		}

		$this->setup_css();
		$this->setup_delay_js();
	}

	public function setup_delay_js()
	{
		add_filter('debloat/delay_js_includes', function($includes) {
			$includes = array_merge($includes, [
				// Embeds need iframe message, can't be delayed.
				// 'id:wp-embed',
				'id:comment-reply',
			]);

			return $includes;
		});

		add_filter('debloat/delay_js_excludes', function($excludes) {
			$excludes = array_merge($excludes, [
				// Always skip for switcher.
				'BunyadSchemeKey',
			]);

			// If slider is enabled.
			if (Bunyad::options()->home_slider || wp_script_is('jquery-slick', 'enqueued')) {
				$excludes[] = 'cheerup/*';
				$excludes[] = 'id:jquery*';
			}

			return $excludes;
		});
	}

	public function setup_css()
	{
		add_filter('debloat/remove_css_includes', function($include) {

			$include[] = 'id:global-style-inline';
			$include[] = 'id:wp-mediaelement';
			$include[] = 'id:mediaelement';

			return $include;
		});

		$this->allow_selectors = [
			[
				'type'   => 'any',
				'sheet'  => 'id:cheerup-',
				'search' => [
					'.off-canvas-active', 
					'.nav-off-canvas*',
					'.lazyloaded',
					'.lazyload',
					'.lazyloading',
					'.active',
					'.inactive',
					'.item-active',
					'.search-modal',
					'.is-open',
					// can be conditional
					'.post-share-b.all',
					'.mobile-menu *',
					'.theiaStickySidebar',
					'.tsi-spin',
					'.tsi-chevron-down',
					'.tsi-chevron-up',
					
					// Post formats for AJAX load
					'tsi-play',
					'tsi-clone',
					
					// For pagination numbers.
					'.tsi-angle-right',
					'.tsi-angle-left',

					// Needed for multi-page slideshow AJAX.
					'.tsi-chevron-left',
					// '.tsi-chevron-right',

					// Block filters and other loading (load button)
					'.loading',

					// All animations including fade-in-lg etc.
					'.fade',
					'.fade.in',
					'.fade-in-*',

					// Header
					'.sticky-bar',
					'.sticky-logo',

					'.main-head .parallax'
				],
			],
			[
				'type'  => 'class',
				'class' => 'has-lb',
				'search' => ['*.mfp-*'],
			],
			[
				'type'  => 'class',
				'class' => 'woocommerce',
				'search' => ['.block-head-legacy'],
			],
			[
				'type'  => 'class',
				'class' => 'common-slider',
				// Other allows are applied to all sheets, to possibly allow child stylesheets.
				'sheet' => 'id:cheerup-',
				'search' => [
					'*.slick-*',
					'.common-slider',
					'.loaded',
					'.tsi-angle-left',
					'.tsi-angle-right',
					'.next-arrow',
					'.prev-arrow',
				]
			],
			[
				'type'  => 'class',
				'class' => 'widget-slider',
				// Other allows are applied to all sheets, to possibly allow child stylesheets.
				'sheet' => 'id:cheerup-',
				'search' => [
					'*.slick-*',
					'.widget-slider*',
					'.tsi-angle-left',
					'.tsi-angle-right',
				]
			],
			[
				'type'  => 'class',
				'class' => 'posts-carousel',
				// Other allows are applied to all sheets, to possibly allow child stylesheets.
				'sheet' => 'id:cheerup-',
				'search' => [
					'*.slick-*',
					'.posts-carousel*',
					'.tsi-angle-left',
					'.tsi-angle-right',
				]
			],
			[
				'type'   => 'class',
				'class'  => 'load-button',
				'sheet'  => 'id:cheerup-',
				'search' => [
					'.format-icon',
					'.cat-label'
				]
			],
			// [
			// 	'type'  => 'prefix',
			// 	'class' => 's-dark',
			// ],
			// [
			// 	'type'  => 'prefix',
			// 	'class' => 'site-s-dark',
			// ],
			// [
			// 	'type'  => 'prefix',
			// 	'class' => 's-light',
			// ],
			// [
			// 	'type'  => 'prefix',
			// 	'class' => 'site-s-light',
			// ],
		];

		if (is_single()) {
			array_push(
				$this->allow_selectors,
				...[
					[
						'type'   => 'class',
						'class'  => 'post-share-float',
						'sheet' => 'id:cheerup-',
						'search' => [
							'.has-share-float*',
							'.is-hidden'
						]
					],
				]
			);
		}

		// Add to debloat allowed.
		add_filter('debloat/allow_css_selectors', function($allow) {
			return array_merge($allow, $this->allow_selectors);
		});

		// Skip WooCommerce removals.
		add_filter('debloat/remove_css_excludes', function($exclude) {
			array_push($exclude, ...[
				'id:cheerup-woocommerce',
			]);

			return $exclude;
		});

	}
}

// init and make available in Bunyad::get('debloat')
Bunyad::register('integrations_debloat', array(
	'class' => 'Bunyad_Theme_Debloat',
	'init' => true
));