<?php
/**
 * Functions relating to the social functionality.
 */
class Bunyad_Theme_Social
{	
	
	public function __construct() 
	{
		add_filter('sphere_social_follow_options', array($this, 'follow_options'));
		add_filter('sphere_theme_docs_url', array($this, 'docs_url'));
	}
	
	/**
	 * Filter: Modify default customizer options for social follow
	 * 
	 * @see \Sphere\Core\SocialFollow\Module::add_theme_options()
	 */
	public function follow_options($options)
	{
		$supported = [
			'general',
			'facebook',
			'twitter',
			'pinterest',
			'instagram',
			'youtube',
			'vimeo',
			'soundcloud',
			'linkedin',
			'twitch',
			'reddit',
			'tiktok',
			'telegram',
			'whatsapp'
		];

		foreach ($options['sections'] as $key => $section) {
			if (!in_array($key, $supported)) {
				unset($options['sections'][$key]);
			}
		}

		$options['title'] = esc_html_x('Social Counters', 'Admin', 'cheerup');
		$options['desc']  = sprintf(
			'Note: These settings are for Social Follow widget. For normal social settings, go to %sSocial Media Links%s',
			'<a href="#" class="focus-link" data-section="bunyad-misc-social">', '</a>'
		);
		$options['sections']['general']['fields']['sf_counters']['value'] = 0;
	
		// Change default labels
		$labels = $this->get_services();
		foreach (array_keys($options['sections']) as $id) {
			
			if (!array_key_exists($id, $labels)) {
				continue;
			}
			
			$options['sections'][$id]['fields']["sf_{$id}_label"]['value'] = $labels[$id]['label'];
		}
		
		return $options;
	}
	
	public function docs_url($url) {
		return 'https://theme-sphere.com/docs/cheerup/';
	}
	
	/**
	 * Get an array of services supported at different locations
	 * such as Top bar social icons.
	 */
	public function get_services()
	{
		$services = [
			'facebook' => [
				'icon'  => 'facebook',
				'label' => esc_html__('Facebook', 'cheerup')
			],

			'twitter' => [
				'icon'  => 'twitter',
				'label' => esc_html__('X (Twitter)', 'cheerup')
			],

			'instagram' => [
				'icon'  => 'instagram',
				'label' => esc_html__('Instagram', 'cheerup')
			],

			'pinterest' => [
				'icon'  => 'pinterest-p',
				'label' => esc_html__('Pinterest', 'cheerup')
			],

			'bloglovin' => [
				'icon'  => 'heart',
				'label' => esc_html__('BlogLovin', 'cheerup')
			],

			'rss' => [
				'icon'  => 'rss',
				'label' => esc_html__('RSS', 'cheerup')
			],

			'youtube' => [
				'icon'  => 'youtube-play',
				'label' => esc_html__('YouTube', 'cheerup')
			],

			'dribbble' => [
				'icon'  => 'dribbble',
				'label' => esc_html__('Dribbble', 'cheerup')
			],

			'tumblr' => [
				'icon'  => 'tumblr',
				'label' => esc_html__('Tumblr', 'cheerup')
			],

			'linkedin' => [
				'icon'  => 'linkedin',
				'label' => esc_html__('LinkedIn', 'cheerup')
			],

			'flickr' => [
				'icon'  => 'flickr',
				'label' => esc_html__('Flickr', 'cheerup')
			],

			'soundcloud' => [
				'icon'  => 'soundcloud',
				'label' => esc_html__('SoundCloud', 'cheerup')
			],

			'vimeo' => [
				'icon'  => 'vimeo',
				'label' => esc_html__('Vimeo', 'cheerup')
			],

			'lastfm' => [
				'icon'  => 'lastfm',
				'label' => esc_html__('Last.fm', 'cheerup')
			],

			'steam' => [
				'icon'  => 'steam',
				'label' => esc_html__('Steam', 'cheerup')
			],

			'vk' => [
				'icon'  => 'vk',
				'label' => esc_html__('VKontakte', 'cheerup')
			],

			'twitch' => [
				'icon'  => 'twitch',
				'label' => esc_html__('Twitch', 'cheerup')
			],

			'discord' => [
				'icon'  => 'discord',
				'label' => esc_html__('Discord', 'cheerup')
			],

			'whatsapp' => [
				'icon'  => 'whatsapp',
				'label' => esc_html__('WhatsApp', 'cheerup')
			],

			'reddit' => [
				'icon'  => 'reddit-alien',
				'label' => esc_html__('Reddit', 'cheerup')
			],

			'tiktok' => [
				'icon'  => 'tiktok',
				'label' => esc_html__('TikTok', 'cheerup')
			],

			'telegram' => [
				'icon'  => 'telegram',
				'label' => esc_html__('Telegram', 'cheerup')
			],
		];
		
		return apply_filters('bunyad_social_services', $services);
	}
}

// init and make available in Bunyad::get('social')
Bunyad::register('social', array(
	'class' => 'Bunyad_Theme_Social',
	'init' => true
));